==> commons-utils-2.4.0-sources.jar: org/seppiko/commons/utils/http/URIUtil.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.net.URI;

/**
 * URI Util
 *
 * [scheme ":"] ["//" authority] "/" path ["?" query] ["#" fragment]
 * authority = [userinfo "@"] host [":" port]
 * userinfo = username [":" password]
 *
 * But the URI definition requires that the scheme must be used.
 *
 * @author Leonard Woo
 */
public class URIUtil {

  /**
   * get URI object
   *
   * @param uri URI address (like url)
   * @return URI object
   * @throws NullPointerException If uri string is null
   * @throws IllegalArgumentException If the given string violates RFC 2396
   */
  public static URI getUri(String uri) throws NullPointerException, IllegalArgumentException {
    return URI.create(uri);
  }

  /**
   * Get last path name (e.g. filename)
   *
   * @param uri URI
   * @return last path content e.g. filename
   * @throws IllegalArgumentException uri is not legal URI
   * @throws NullPointerException uri is null
   */
  public static String getLastPathname(String uri) throws IllegalArgumentException, NullPointerException {
    String filename = getUri(uri).getPath();
    return filename.substring(filename.lastIndexOf('/') + 1);
  }

}

==> commons-utils-2.5.0-sources.jar: org/seppiko/commons/utils/http/URIUtil.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.utils.http;

import java.net.URI;
import java.util.Objects;
import org.seppiko.commons.utils.NumberUtil;
import org.seppiko.commons.utils.StringUtil;

/**
 * URI Util
 *
 * [scheme ":"] ["//" authority] "/" path ["?" query] ["#" fragment]
 * authority = [userinfo "@"] host [":" port]
 * userinfo = username [":" password]
 *
 * But the URI definition requires that the scheme must be used.
 *
 * @author Leonard Woo
 */
public class URIUtil {

  /**
   * get URI object
   *
   * @param uri URI address (like url)
   * @return URI object
   * @throws NullPointerException If uri string is null
   * @throws IllegalArgumentException If the given string violates RFC 2396
   */
  public static URI getUri(String uri) throws NullPointerException, IllegalArgumentException {
    return URI.create(uri);
  }

  /**
   * Get last path name (e.g. filename)
   *
   * @param uri URI
   * @return last path content e.g. filename
   * @throws IllegalArgumentException uri is not legal URI
   * @throws NullPointerException uri is null
   */
  public static String getLastPathname(String uri) throws IllegalArgumentException, NullPointerException {
    String filename = getUri(uri).getPath();
    return filename.substring(filename.lastIndexOf('/') + 1);
  }

  /**
   * get file extension
   *
   * @param filename file name e.g. last pathname.
   * @return file extension, if not found return null.
   * @throws NullPointerException filename is null.
   */
  public static String getFileExtension(String filename) throws NullPointerException {
    Objects.requireNonNull(filename);
    if (filename.matches("\\.\\w{3,4}$")) {
      return filename.substring(filename.lastIndexOf('.') + 1);
    }
    return null;
  }

}
